@@ -17,7 +17,6 @@ tar_file="xmlsec1-$version.tar.gz"
 sig_file="xmlsec1-$version.sig"
 rc_tar_file="xmlsec1-$version-$rc.tar.gz"
 rc_sig_file="xmlsec1-$version-$rc.sig"
-git_1_2_x_branch="xmlsec-1_2_x"
 git_release_branch=`echo "xmlsec-$version" | sed 's/\./_/g'`
 git_version_tag=`echo $version | sed 's/\./_/g'`
 
@@ -34,13 +33,10 @@ cd "$build_root"
 echo "============== Checking out the module '$git_url'"
 git clone $git_uri
 cd xmlsec
-if [ x"$rc" != x ]; then
-    echo "============== Switching to release branch '$git_release_branch' for RC build '$rc'"
-    git checkout $git_release_branch
-else
-    echo "============== Switching to 1.2.x branch '$git_1_2_x_branch'"
-    git checkout $git_1_2_x_branch
-fi
+#if [ x"$rc" != x ]; then
+#    echo "============== Switching to release branch '$git_release_branch' for RC build '$rc'"
+#    git checkout $git_release_branch
+#fi
 find . -name ".git" | xargs rm -r
 
 echo "============== Building xmlsec1-$version"
@@ -66,7 +62,12 @@ fi
 
 if [ x"$rc" = x ]; then
      echo "============== Tagging the release $version in the github"
-     echo "RUN MANUALLY: git tag -a "xmlsec-$git_version_tag" -m 'XMLSec release $version'"
+     echo "RUN MANUALLY: git tag -a "xmlsec_$git_version_tag" -m 'XMLSec release $version'"
+     echo "RUN MANUALLY: git push --follow-tags"
+else
+     echo "============== Tagging the release $version-$rc in the github"
+     echo "RUN MANUALLY: git tag -a "xmlsec_${version}-$rc" -m 'XMLSec release $version-$rc'"
+     echo "RUN MANUALLY: git tag -a "xmlsec_${git_version_tag}_$rc" -m 'XMLSec release $version-$rc'"
      echo "RUN MANUALLY: git push --follow-tags"
 fi
 
