@@ -6,14 +6,14 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_CAST_HELPERS_H__
 #define __XMLSEC_CAST_HELPERS_H__
 
 
 #ifndef XMLSEC_PRIVATE
-#error "private.h file contains private xmlsec definitions and should not be used outside xmlsec or xmlsec-$crypto libraries"
+#error "cast_helpers.h file contains private xmlsec definitions and should not be used outside xmlsec or xmlsec-$crypto libraries"
 #endif /* XMLSEC_PRIVATE */
 
 #include <limits.h>
@@ -72,6 +72,12 @@
         xmlSecByte, (dstVal), "%d", 0, 255,                                    \
         errorAction, (errorObject))
 
+/* Safe cast with limits check: unsigned int -> xmlSecByte (assume unsigned int > 0) */
+#define XMLSEC_SAFE_CAST_UINT_TO_BYTE(srcVal, dstVal, errorAction, errorObject) \
+    XMLSEC_SAFE_CAST_MAX_CHECK(unsigned int, (srcVal), "%u",                    \
+        xmlSecByte, (dstVal), "%d", 0, 255,                                     \
+        errorAction, (errorObject))
+
 /* Safe cast with limits check: xmlSecSize -> xmlSecByte (assume xmlSecSize > 0) */
 #define XMLSEC_SAFE_CAST_SIZE_TO_BYTE(srcVal, dstVal, errorAction, errorObject) \
     XMLSEC_SAFE_CAST_MAX_CHECK(xmlSecSize, (srcVal), XMLSEC_SIZE_FMT,           \
@@ -332,20 +338,10 @@
 
 #endif /* (ULONG_MAX > XMLSEC_SIZE_MAX) */
 
-/* Safe cast with limits check: size_t -> xmlSecSize (assume size_t >= 0) */
-#if (SIZE_MAX > XMLSEC_SIZE_MAX)
-
-#define XMLSEC_SAFE_CAST_SIZE_T_TO_SIZE(srcVal, dstVal, errorAction, errorObject) \
-    XMLSEC_SAFE_CAST_MAX_CHECK(size_t, (srcVal), XMLSEC_SIZE_T_FMT,              \
-        xmlSecSize, (dstVal), XMLSEC_SIZE_FMT, XMLSEC_SIZE_MIN, XMLSEC_SIZE_MAX, \
-        errorAction, (errorObject))
-
-#else /* (SIZE_MAX > XMLSEC_SIZE_MAX) */
-
+/* Safe cast with limits check: size_t -> xmlSecSize (same type) */
 #define XMLSEC_SAFE_CAST_SIZE_T_TO_SIZE(srcVal, dstVal, errorAction, errorObject) \
     (dstVal) = (srcVal);
 
-#endif /* (SIZE_MAX > XMLSEC_SIZE_MAX) */
 
 /******************************************************************************
  *
