@@ -46,7 +46,10 @@
 #include <openssl/engine.h>
 #include <openssl/x509_vfy.h>
 #include <openssl/x509.h>
+
+#ifndef OPENSSL_IS_BORINGSSL
 #include <openssl/ui.h>
+#endif /* OPENSSL_IS_BORINGSSL */
 
 #ifndef XMLSEC_OPENSSL_NO_STORE
 #include <openssl/store.h>
@@ -186,27 +189,6 @@ xmlSecOpenSSLAppShutdown(void) {
     return(0);
 }
 
-
-/**
- * xmlSecOpenSSLAppKeyLoad:
- * @filename:           the key filename.
- * @format:             the key file format.
- * @pwd:                the key file password.
- * @pwdCallback:        the key password callback.
- * @pwdCallbackCtx:     the user context for password callback.
- *
- * Deprecated, use @xmlSecOpenSSLAppKeyLoadEx function instead. Reads key from the a file.
- *
- * Returns: pointer to the key or NULL if an error occurs.
- */
-xmlSecKeyPtr
-xmlSecOpenSSLAppKeyLoad(const char *filename, xmlSecKeyDataFormat format,
-                        const char *pwd, void* pwdCallback,
-                        void* pwdCallbackCtx) {
-    return(xmlSecOpenSSLAppKeyLoadEx(filename, xmlSecKeyDataTypeUnknown, format,
-        pwd, pwdCallback, pwdCallbackCtx));
-}
-
 /**
  * xmlSecOpenSSLAppKeyLoadEx:
  * @filename:           the key filename.
@@ -771,6 +753,7 @@ xmlSecOpenSSLAppCheckCertMatchesKey(EVP_PKEY * pKey,  X509 * cert) {
     return(1);
 }
 
+#if !defined(XMLSEC_OPENSSL_NO_STORE)
 static X509 *
 xmlSecOpenSSLAppFindKeyCert(EVP_PKEY * pKey, STACK_OF(X509) * certs) {
     X509 * cert;
@@ -804,6 +787,8 @@ xmlSecOpenSSLAppFindKeyCert(EVP_PKEY * pKey, STACK_OF(X509) * certs) {
     /* not found */
     return(NULL);
 }
+#endif /* !defined(XMLSEC_OPENSSL_NO_STORE) */
+
 #endif /* XMLSEC_NO_X509 */
 
 static xmlSecKeyPtr
@@ -907,7 +892,6 @@ xmlSecOpenSSLAppStoreKeyLoad(const char *uri, xmlSecKeyDataType type, const char
             ret = sk_X509_push(certs, cert);
             if(ret <= 0) {
                 xmlSecOpenSSLError("sk_X509_push", NULL);
-                X509_free(cert);
                 goto done;
             }
             cert = NULL; /* owned by certs now */
@@ -957,6 +941,9 @@ xmlSecOpenSSLAppStoreKeyLoad(const char *uri, xmlSecKeyDataType type, const char
     /* success! */
 
 done:
+    if(cert != NULL) {
+        X509_free(cert);
+    }
     if(pPrivKey != NULL) {
         EVP_PKEY_free(pPrivKey);
     }
@@ -1091,9 +1078,9 @@ xmlSecOpenSSLAppKeyCertLoadBIO(xmlSecKeyPtr key, BIO* bio, xmlSecKeyDataFormat f
     xmlSecKeyDataFormat certFormat;
     xmlSecKeyDataPtr x509Data = NULL;
     X509 *cert = NULL;
+    int isKeyCert = 0;
     int ret;
     int res = -1;
-    int isKeyCert = 0;
 
     xmlSecAssert2(key != NULL, -1);
     xmlSecAssert2(bio != NULL, -1);
@@ -1125,8 +1112,7 @@ xmlSecOpenSSLAppKeyCertLoadBIO(xmlSecKeyPtr key, BIO* bio, xmlSecKeyDataFormat f
         goto done;
     }
 
-    /* do we want to add this cert as a key cert? don't bother checking
-     * if the key cert is already set */
+    /* do we want to add this cert as a key cert? */
     if(xmlSecOpenSSLKeyDataX509GetKeyCert(x509Data) == NULL) {
         EVP_PKEY* pKey;
 
@@ -1135,6 +1121,10 @@ xmlSecOpenSSLAppKeyCertLoadBIO(xmlSecKeyPtr key, BIO* bio, xmlSecKeyDataFormat f
         if(pKey != NULL) {
             /* ignore errors here */
             ret = xmlSecOpenSSLAppCheckCertMatchesKey(pKey,  cert);
+            if(ret < 0) {
+                xmlSecInternalError("xmlSecOpenSSLAppCheckCertMatchesKey", NULL);
+                goto done;
+            }
             if(ret == 1) {
                 isKeyCert = 1;
             }
